==> openGion6.0.0.3_dev.zip: uap/webapps/gf/src/org/opengion/fukurou/taglet/TagletValue.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.fukurou.taglet;

import com.sun.tools.doclets.Taglet;
import com.sun.javadoc.Tag;
import java.util.Map;

/**
 * ソースコメントから、Javadoc を作成する場合のカスタムタグ情報を作成する
 * Taglet インターフェースの実装クラスを作成します。
 * og.value タグ(形式サンプル)を処理します。
 *
 * このタグは、インラインタグ 定義されているため、@og.tag などに含まれると処理されません。
 * そこで、 DocletTagWriter#printTag( final Tag[] tag ) に処理を追加する必要があります。
 *
 * @og.rev 5.5.4.1 (2012/07/06) 新規作成
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class TagletValue extends AbstractTaglet {

	private static final String NAME   = "og.value";

	/**
	 * このタグレットがインラインタグで
	 * 使用されている場合、true を返します。
	 * そうでない場合については false が設定されます。
	 *
	 * @return インラインタグの場合は true、そうでない場合は false を返します
	 */
	@Override
	public boolean isInlineTag() {
		return true;
	}

	/**
	 * 実行時にドックレットがタグレットを読み込んで使用するには、
	 * そのタグレットが、次のシグニチャでマップ を引数として受け取る、
	 * レジスタ と呼ばれる static メソッドをもっている必要があります。
	 * このメソッドは、タグレット名をキーとして、カスタムタグレットの
	 * インスタンスをマップに追加します。 タグレットをオーバーライドする場合、
	 * 名前の競合を避けるため、新しいタグレットのインスタンスをマップに
	 * 追加する前に、オーバーライドされる側のタグレットをマップから
	 * 削除する必要があります。
	 *
	 * @param tagletMap タグレットマップ
	 */
	public static void register( final Map<String,Taglet> tagletMap ) {
	   TagletValue tagTag = new TagletValue();
	   Taglet tag = tagletMap.get(NAME);
	   if(tag != null) {
		   tagletMap.remove(NAME);
	   }
	   tagletMap.put(NAME, tagTag);
	}

	/**
	 * このカスタムタグの名前を返します。
	 *
	 * @return カスタムタグの名前
	 */
	public String getName() {
		return NAME;
	}

	/**
	 * このカスタムタグのタグ表現を受け取り、
	 * 文字列としての表現を返し、生成されたページに出力します。
	 *
	 * @param tagTag このカスタムタグのタグ表現
	 *
	 * @return このタグの文字列としての表現
	 */
	public String toString( final Tag tagTag ) {
		return DocletUtil.valueTag( tagTag );
	}

	/**
	 * このカスタムタグのタグ表現の配列を受け取り、
	 * 文字列としての表現を返し、生成されたページに出力します。
	 * このタグレットがインラインタグを表す場合、
	 * このメソッドは null を返します。
	 *
	 * @param tagTags	このカスタムタグを表すタグの配列
	 *
	 * @return このタグの文字列としての表現
	 */
	public String toString( final Tag[] tagTags ) {
		if(tagTags.length == 0) {
			return null;
		}
		StringBuilder result = new StringBuilder();
		for(int i = 0; i < tagTags.length; i++) {
			result.append( DocletUtil.valueTag( tagTags[i] ) );
		}
		return result.toString();
	}
}

==> openGion6.1.0.0_dev.zip: uap/webapps/gf/src/org/opengion/fukurou/taglet/TagletValue.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.fukurou.taglet;

import com.sun.tools.doclets.Taglet;
import com.sun.javadoc.Tag;
import java.util.Map;

// import static org.opengion.fukurou.util.HybsConst.BUFFER_MIDDLE;	// 6.1.0.0 (2014/12/26) refactoring

/**
 * ソースコメントから、Javadoc を作成する場合のカスタムタグ情報を作成する
 * Taglet インターフェースの実装クラスを作成します。
 * og.value タグ(形式サンプル)を処理します。
 *
 * このタグは、インラインタグ 定義されているため、@og.tag などに含まれると処理されません。
 * そこで、 DocletTagWriter#printTag( final Tag[] tag ) に処理を追加する必要があります。
 *
 * @og.rev 5.5.4.1 (2012/07/06) 新規作成
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class TagletValue extends AbstractTaglet {

	private static final String NAME   = "og.value";

	/**
	 * このタグレットがインラインタグで
	 * 使用されている場合、true を返します。
	 * そうでない場合については false が設定されます。
	 *
	 * @return インラインタグの場合は true、そうでない場合は false を返します
	 */
	@Override
	public boolean isInlineTag() {
		return true;
	}

	/**
	 * 実行時にドックレットがタグレットを読み込んで使用するには、
	 * そのタグレットが、次のシグニチャでマップ を引数として受け取る、
	 * レジスタ と呼ばれる static メソッドをもっている必要があります。
	 * このメソッドは、タグレット名をキーとして、カスタムタグレットの
	 * インスタンスをマップに追加します。 タグレットをオーバーライドする場合、
	 * 名前の競合を避けるため、新しいタグレットのインスタンスをマップに
	 * 追加する前に、オーバーライドされる側のタグレットをマップから
	 * 削除する必要があります。
	 *
	 * @param tagletMap タグレットマップ
	 */
	public static void register( final Map<String,Taglet> tagletMap ) {
	   final TagletValue tagTag = new TagletValue();
	   final Taglet tag = tagletMap.get(NAME);
	   if(tag != null) {
		   tagletMap.remove(NAME);
	   }
	   tagletMap.put(NAME, tagTag);
	}

	/**
	 * このカスタムタグの名前を返します。
	 *
	 * @return カスタムタグの名前
	 */
	public String getName() {
		return NAME;
	}

	/**
	 * このカスタムタグのタグ表現を受け取り、
	 * 文字列としての表現を返し、生成されたページに出力します。
	 *
	 * @param tagTag このカスタムタグのタグ表現
	 *
	 * @return このタグの文字列としての表現
	 */
	public String toString( final Tag tagTag ) {
		return DocletUtil.valueTag( tagTag );
	}

	/**
	 * このカスタムタグのタグ表現の配列を受け取り、
	 * 文字列としての表現を返し、生成されたページに出力します。
	 * このタグレットがインラインタグを表す場合、
	 * このメソッドは null を返します。
	 *
	 * @param tagTags	このカスタムタグを表すタグの配列
	 *
	 * @return このタグの文字列としての表現
	 * @see		com.sun.tools.doclets.Taglet#toString( Tag[] )
	 */
	public String toString( final Tag[] tagTags ) {
		if(tagTags.length == 0) {
			return null;
		}
		final StringBuilder result = new StringBuilder( BUFFER_MIDDLE );
		for(int i = 0; i < tagTags.length; i++) {
			result.append( DocletUtil.valueTag( tagTags[i] ) );
		}
		return result.toString();
	}
}
